pub enum PaymentMethodType {
LightningBolt11,
LightningBolt12,
OnChain,
Cashu,
}Expand description
The method that a PossiblyResolvedPaymentMethod will eventually resolve to.
This is useful to determine if you support the required payment mechanism for a
ConfigurableAmountPaymentInstructions before you display an amount selector to the wallet
owner.
Variants
LightningBolt11
The PossiblyResolvedPaymentMethod will eventually resolve to a
PaymentMethod::LightningBolt11.
LightningBolt12
The PossiblyResolvedPaymentMethod will eventually resolve to a
PaymentMethod::LightningBolt12.
OnChain
The PossiblyResolvedPaymentMethod will eventually resolve to a
PaymentMethod::OnChain.
Cashu
The PossiblyResolvedPaymentMethod will eventually resolve to a
PaymentMethod::Cashu.